@@ -22,7 +22,9 @@ from zope.component import queryMultiAdapter
 from zope.container.interfaces import INameChooser
 from zope.event import notify
 from zope.globalrequest import getRequest
+from zope.lifecycleevent import Attributes
 from zope.lifecycleevent import ObjectCreatedEvent
+from zope.lifecycleevent import ObjectModifiedEvent
 
 import json
 import logging
@@ -335,6 +337,12 @@ def create_item_runner(  # noqa
                         )
                     )
                     plone_scale_generate_on_save(obj, request, image_fieldname)
+            else:
+                if deserializer.modified:
+                    descriptions = []
+                    for interface, names in deserializer.modified.items():
+                        descriptions.append(Attributes(interface, *names))
+                    notify(ObjectModifiedEvent(obj, *descriptions))
 
             # Set UUID - TODO: add to p.restapi
             if data.get("UID"):
@@ -401,9 +409,6 @@ def create_item_runner(  # noqa
             for user, roles in opts.get("local_roles", {}).items():
                 obj.manage_setLocalRoles(user, roles)
 
-            # reindex object
-            obj.reindexObject()
-
         except Exception as e:
             container_path = "/".join(container.getPhysicalPath())
             message = f'Could not edit the fields and properties for object {container_path}/{id_} (type: "{type_}", container: "{container_path}", id: "{id_}", title: "{title}") because: {e}'
